==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/ItemToolTipLayerDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AnnotationLayerDescriptionMetadata } from "./AnnotationLayerDescriptionMetadata";
import { ItemToolTipLayerDescription } from "./ItemToolTipLayerDescription";
/**
 * @hidden
 */
export let ItemToolTipLayerDescriptionMetadata = /*@__PURE__*/ (() => {
    class ItemToolTipLayerDescriptionMetadata extends Base {
        static b(a) {
            if (ItemToolTipLayerDescriptionMetadata.a == null) {
                ItemToolTipLayerDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ItemToolTipLayerDescriptionMetadata.c(ItemToolTipLayerDescriptionMetadata.a);
            }
            if (a.k(ItemToolTipLayerDescriptionMetadata.a)) {
                return;
            }
            a.ab(ItemToolTipLayerDescriptionMetadata.a);
        }
        static c(a) {
            AnnotationLayerDescriptionMetadata.c(a);
            a.item("TargetSeriesName", "String");
            a.item("TargetSeriesRef", "(w:TargetSeries,wf:TargetSeries)DataRef::object");
            a.item("UseInterpolation", "Boolean");
            a.item("SkipUnknownValues", "Boolean");
        }
        static d(a) {
            ItemToolTipLayerDescriptionMetadata.b(a);
            a.ad("ItemToolTipLayer", () => new ItemToolTipLayerDescription());
            a.ac("ItemToolTipLayer", ItemToolTipLayerDescriptionMetadata.a);
        }
    }
    ItemToolTipLayerDescriptionMetadata.$t = /*@__PURE__*/ markType(ItemToolTipLayerDescriptionMetadata, 'ItemToolTipLayerDescriptionMetadata');
    ItemToolTipLayerDescriptionMetadata.a = null;
    return ItemToolTipLayerDescriptionMetadata;
})();

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm2015/lib/ItemToolTipLayerDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AnnotationLayerDescriptionMetadata } from "./AnnotationLayerDescriptionMetadata";
import { ItemToolTipLayerDescription } from "./ItemToolTipLayerDescription";
/**
 * @hidden
 */
export let ItemToolTipLayerDescriptionMetadata = /*@__PURE__*/ (() => {
    class ItemToolTipLayerDescriptionMetadata extends Base {
        static b(a) {
            if (ItemToolTipLayerDescriptionMetadata.a == null) {
                ItemToolTipLayerDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ItemToolTipLayerDescriptionMetadata.c(ItemToolTipLayerDescriptionMetadata.a);
            }
            if (a.k(ItemToolTipLayerDescriptionMetadata.a)) {
                return;
            }
            a.ac(ItemToolTipLayerDescriptionMetadata.a);
        }
        static c(a) {
            AnnotationLayerDescriptionMetadata.c(a);
            a.item("TargetSeriesName", "String");
            a.item("TargetSeriesRef", "(w:TargetSeries,wf:TargetSeries)DataRef::object");
            a.item("UseInterpolation", "Boolean");
            a.item("SkipUnknownValues", "Boolean");
        }
        static d(a) {
            ItemToolTipLayerDescriptionMetadata.b(a);
            a.ae("ItemToolTipLayer", () => new ItemToolTipLayerDescription());
            a.ad("ItemToolTipLayer", ItemToolTipLayerDescriptionMetadata.a);
        }
    }
    ItemToolTipLayerDescriptionMetadata.$t = /*@__PURE__*/ markType(ItemToolTipLayerDescriptionMetadata, 'ItemToolTipLayerDescriptionMetadata');
    ItemToolTipLayerDescriptionMetadata.a = null;
    return ItemToolTipLayerDescriptionMetadata;
})();
